Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(615)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index 9bc41a61d3d939c8079040d0a86a59d45a090474..f6fa8c92e4b25fa5ab674e6b70f6515d0abde492 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -690,7 +690,7 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// Returns the smallest rectangle enclosing all of the painted content
// respecting clipping, masking, filters, opacity, stroke-width and markers
- virtual FloatRect paintInvalidationRectInLocalSVGCoordinates() const;
+ virtual FloatRect visualRectInLocalSVGCoordinates() const;
// This only returns the transform="" value from the SVG element.
// Most callsites want localToParentTransform() instead.
@@ -1351,15 +1351,14 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// Returns the rect that should have paint invalidated whenever this object
// changes. The rect is in the view's coordinate space. This method deals with
// outlines and overflow.
- virtual LayoutRect absoluteClippedOverflowRect() const;
+ virtual LayoutRect absoluteVisualRect() const;
// Returns the rect that should have paint invalidated whenever this object
// changes. The rect is in the object's local coordinate space. This is for
// non-SVG objects and LayoutSVGRoot only.
// SVG objects (except LayoutSVGRoot) should use
// paintInvalidationRectInLocalSVGCoordinates() and map with SVG transforms
// instead.
- virtual LayoutRect localOverflowRectForPaintInvalidation() const;
+ virtual LayoutRect localVisualRect() const;
// Given a rect in the object's coordinate space, mutates the rect into one
// representing the size of its visual painted output as if |ancestor| was the
@@ -1595,19 +1594,16 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
bool isRelayoutBoundaryForInspector() const;
- // The previous paint invalidation rect, in the the space of the paint
- // invalidation container (*not* the graphics layer that paints
- // this object).
- LayoutRect previousPaintInvalidationRectIncludingCompositedScrolling(
+ // The previous visual rect, in the the space of the paint invalidation
+ // container (*not* the graphics layer that paints this object).
+ LayoutRect previousVisualRectIncludingCompositedScrolling(
const LayoutBoxModelObject& paintInvalidationContainer) const;
// The returned rect does *not* account for composited scrolling.
- const LayoutRect& previousPaintInvalidationRect() const {
- return m_previousPaintInvalidationRect;
- }
+ const LayoutRect& previousVisualRect() const { return m_previousVisualRect; }
- // Called when the previous paint invalidation rect(s) is no longer valid.
- virtual void clearPreviousPaintInvalidationRects();
+ // Called when the previous visual rect(s) is no longer valid.
+ virtual void clearPreviousVisualRects();
// Only adjusts if the paint invalidation container is not a composited
// scroller.
@@ -1712,8 +1708,8 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
m_layoutObject.ensureIsReadyForPaintInvalidation();
}
- void setPreviousPaintInvalidationRect(const LayoutRect& r) {
- m_layoutObject.setPreviousPaintInvalidationRect(r);
+ void setPreviousVisualRect(const LayoutRect& r) {
+ m_layoutObject.setPreviousVisualRect(r);
}
void setPreviousPositionFromPaintInvalidationBacking(const LayoutPoint& p) {
m_layoutObject.setPreviousPositionFromPaintInvalidationBacking(p);
@@ -1721,8 +1717,8 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
void setPreviousBackgroundObscured(bool b) {
m_layoutObject.setPreviousBackgroundObscured(b);
}
- void clearPreviousPaintInvalidationRects() {
- m_layoutObject.clearPreviousPaintInvalidationRects();
+ void clearPreviousVisualRects() {
+ m_layoutObject.clearPreviousVisualRects();
}
protected:
@@ -1909,8 +1905,8 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
virtual void computeSelfHitTestRects(Vector<LayoutRect>&,
const LayoutPoint& layerOffset) const {}
- void setPreviousPaintInvalidationRect(const LayoutRect& rect) {
- m_previousPaintInvalidationRect = rect;
+ void setPreviousVisualRect(const LayoutRect& rect) {
+ m_previousVisualRect = rect;
}
#if ENABLE(ASSERT)
@@ -1958,12 +1954,11 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
}
private:
- // Adjusts a paint invalidation rect in the space of
- // |m_previousPaintInvalidationRect| and
- // |m_previousPositionFromPaintInvalidationBacking|
- // to be in the space of the |paintInvalidationContainer|, if needed. They can
- // be different only if |paintInvalidationContainer| is a composited scroller.
- void adjustInvalidationRectForCompositedScrolling(
+ // Adjusts a visual rect in the space of |m_previousVisualRect| and
+ // |m_previousPositionFromPaintInvalidationBacking| to be in the space of the
+ // |paintInvalidationContainer|, if needed. They can be different only if
+ // |paintInvalidationContainer| is a composited scroller.
+ void adjustVisualRectForCompositedScrolling(
LayoutRect&,
const LayoutBoxModelObject& paintInvalidationContainer) const;
@@ -2372,10 +2367,10 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// Store state between styleWillChange and styleDidChange
static bool s_affectsParentBlock;
- // This stores the paint invalidation rect from the previous frame. This rect
- // does *not* account for composited scrolling. See
- // adjustInvalidationRectForCompositedScrolling().
- LayoutRect m_previousPaintInvalidationRect;
+ // This stores the visual rect from the previous frame. This rect does *not*
+ // account for composited scrolling. See
+ // adjustVisualRectForCompositedScrolling().
+ LayoutRect m_previousVisualRect;
// This stores the position in the paint invalidation backing's coordinate.
// It is used to detect layoutObject shifts that forces a full invalidation.
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutMultiColumnSet.cpp ('k') | third_party/WebKit/Source/core/layout/LayoutObject.cpp » ('j') | no next file with comments »
@@ -1351,15 +1351,14 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// Returns the rect that should have paint invalidated whenever this object
// changes. The rect is in the object's local coordinate space. This is for
- // non-SVG objects and LayoutSVGRoot only.
- // SVG objects (except LayoutSVGRoot) should use
- // paintInvalidationRectInLocalSVGCoordinates() and map with SVG transforms
+ // non-SVG objects and LayoutSVGRoot only. SVG objects (except LayoutSVGRoot)
+ // should use visualRectInLocalSVGCoordinates() and map with SVG transforms
// instead.

Powered by Google App Engine
This is Rietveld 408576698